<?php
/**
 * Created by PhpStorm.
 * User: Villatheme-Thanh
 * Date: 06-06-19
 * Time: 8:31 AM
 */

namespace WACVP\Inc\Facebook;

use WACVP\Inc\Data;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class FB_Plugin {
	protected static $instance = null;
	private $settings;

	public function __construct() {
		$this->settings = Data::get_params();

		add_action( 'init', array( $this, 'facebook_verify' ) );
		add_action( 'wp_ajax_wacv_fb_message', array( $this, 'facebook_return' ) );
		add_action( 'wp_ajax_nopriv_wacv_fb_message', array( $this, 'facebook_return' ) );
		add_action( 'wp_ajax_wacv_logout_fb', array( $this, 'logout_fb' ) );
	}

	public static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	public function facebook_verify() {
		if ( isset( $_GET['wacv_fb_verify'] ) && $_GET['wacv_fb_verify'] == 'true' ) {
			$verify_token = $this->settings['app_verify_token'];
			if ( isset( $_REQUEST['hub_mode'] ) && $_REQUEST['hub_mode'] == 'subscribe' ) {
				$challenge        = $_REQUEST['hub_challenge'];
				$hub_verify_token = $_REQUEST['hub_verify_token'];
				if ( $hub_verify_token === $verify_token ) {
					header( 'HTTP/1.1 200 OK' );
					echo esc_html( $challenge );
					wp_die();
				}
			}
			die;
		}
	}

	public function facebook_return() {
		$hub_verify_token = null;
		$verify_token     = $this->settings['app_verify_token'];
		if ( isset( $_REQUEST['hub_mode'] ) && $_REQUEST['hub_mode'] == 'subscribe' ) {
			$challenge        = $_REQUEST['hub_challenge'];
			$hub_verify_token = $_REQUEST['hub_verify_token'];
			if ( $hub_verify_token === $verify_token ) {
				header( 'HTTP/1.1 200 OK' );
				echo esc_html( $challenge );
				wp_die();
			}
		}

		$json     = file_get_contents( 'php://input' );
		$action   = json_decode( $json, true );
		$settings = Data::get_params();

		if ( $settings['fb_test_mode'] ) {
			$messaging = $action['entry'][0]['messaging'][0] ?? [];

			if ( empty( $messaging ) ) {
				wp_die();
			}

			$user_id = ! empty( $messaging['sender']['id'] ) ? absint( $messaging['sender']['id'] ) : '';
			$message = ! empty( $messaging['message']['text'] ) ? strtolower( $messaging['message']['text'] ) : '';

			if ( ! $message ) {
				$message = ! empty( $messaging['postback']['payload'] ) ? strtolower( $messaging['postback']['payload'] ) : '';
			}

			$send_message = '';

			if ( $user_id && $message ) {
				$fb_api            = Api::get_instance();
				$page_id           = $settings['page_id'];
				$user_token        = $settings['user_token'];
				$page_access_token = $fb_api->Get_Access_Token_Page( $user_token, $page_id );
				$page_token        = $page_access_token['access_token'];
				$user_profile      = $fb_api->get_user_profile( $page_token, $user_id );
				$name[]            = $user_profile['first_name'] ?? '';
				$name[]            = $user_profile['last_name'] ?? '';
				$name              = implode( ' ', $name );

				if ( get_option( 'wacv_wait_customer_typing' ) ) {
					delete_option( 'wacv_wait_customer_typing' );
					$message = 'wav_rep_after_monetary';
				}

				switch ( $message ) {
					case 'hi':
					case 'hello':
						$send_message = [ 'text' => "Hi {$name} Welcome to our store. Can I help you?" ];
						break;

					case 'help':
						$send_message = [ 'text' => 'Can I help you?' ];
						break;

					case 'information':
					case 'info':
						$send_message = [ 'text' => 'Please view our information at ' . home_url() ];
						break;

					case 'need help planning my party':
						$send_message = [
							'attachment' => [
								'type'    => 'template',
								'payload' => [
									'template_type' => 'button',
									'text'          => "Hi {$name}. Welcome to our store. I will be happy to help you. Who is the party for?",
									'buttons'       => [
										[
											'type'    => 'postback',
											'title'   => '0 - 5 year old',
											'payload' => 'child'
										],
										[
											'type'    => 'postback',
											'title'   => '6 - 10 year old',
											'payload' => 'kid'
										],
										[
											'type'    => 'postback',
											'title'   => 'Preteen/Teen',
											'payload' => 'teenager'
										],
									]

								]
							]
						];
						break;

					case 'kid':
					case 'child':
					case 'teenager':
						$send_message = [ 'text' => "OK, got it. You're planning a party for a {$message}. If you don't mind my asking, what is your budget?" ];
						update_option( 'wacv_wait_customer_typing', true );
						break;

					case 'wav_rep_after_monetary':
						$send_message = [ 'text' => "OK, got it. What's the first thing you need help with?" ];
						break;

					case 'invitations':
						$send_message = [
							'attachment' => [
								'type'    => 'template',
								'payload' => [
									'template_type' => 'button',
									'text'          => "Try our Invitation Designer app for iPhone or Android",
									'buttons'       => [
										[
											'type'  => 'web_url',
											'title' => 'View app',
											'url'   => 'https://www.evite.com'
										]
									]

								]
							]
						];
						break;
					case 'i need ideas for activities':

						$send_message = [
							'attachment' => [
								'type'    => 'template',
								'payload' => [
									'template_type' => 'button',
									'text'          => "Our favorite resource for all ages is the book Fun Party Crafts for Fun Party Guests",
									'buttons'       => [
										[
											'type'  => 'web_url',
											'title' => 'Fun Party Crafts for Fun Party',
											'url'   => 'https://www.amazon.com/s?k=Fun+Party+Crafts+for+Fun+Party&ref=nb_sb_noss'
										]
									]

								]
							]
						];
						break;

					case 'ok, thanks, bye':
						$send_message = [ 'text' => 'Enjoy your special day. Try our Party Games app for iPhone or Android.' ];
						break;
				}

				try {
					$fb_api->send_message( $page_id, $page_token, $send_message, $user_id );
				} catch ( \Exception $e ) {
//					$e->getMessage();
					error_log( print_r( $e->getMessage(), true ) );
				}
			}
		}
		wp_die();
	}

	public function logout_fb() {
		$new_data = array( 'user_token' => '', 'page_id' => '' );
		$data     = wp_parse_args( $new_data, $this->settings );
		$result   = update_option( 'wacv_params', $data );
		if ( $result ) {
			wp_send_json_success();
		}
		wp_die();
	}

}