<?php
/**
 * Created by PhpStorm.
 * User: Villatheme-Thanh
 * Date: 10-06-19
 * Time: 10:29 AM
 */

namespace WACVP\Inc\Facebook;

use WACVP\Inc\Aes_Ctr;
use WACVP\Inc\Data;
use WACVP\Inc\Query_DB;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Send_Message {

	protected static $instance = null;
	public $query;
	public $fb_api;
	public $settings;
	public $last_time;
	public $last_time_wa;
	public $page_access_token;
	protected $phoneNumberUtil;
	protected $format_e164;

	private function __construct() {

		$this->query    = Query_DB::get_instance();
		$this->fb_api   = Api::get_instance();
		$this->settings = Data::get_params();

		add_action( 'wacv_cron_send_messenger', array( $this, 'send_reminder_messenger' ) );
//		add_action( 'wacv_cron_send_whatsapp', array( $this, 'send_reminder_whatsapp' ) );
		add_action( 'wp_ajax_send_test_whatsapp', array( $this, 'send_test_whatsapp' ) );

	}

	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	public function api_init() {
		require_once WACVP_INCLUDES . 'sms/libphonenumber/autoload.php';
		$this->phoneNumberUtil = \libphonenumber\PhoneNumberUtil::getInstance();
		$this->format_e164     = \libphonenumber\PhoneNumberFormat::E164;
	}

	public function send_reminder_messenger() {
		if ( ! empty( $this->settings['messenger_rules'] ) && ! empty( $this->settings['page_id'] ) ) {
			$messenger_rules = $this->settings['messenger_rules'];
			$multi_lang = array();
			if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
				global $sitepress;
				$default_lang           = $sitepress->get_default_language();
				$wpml_languages              = icl_get_languages( 'skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str' );

				if ( count( $wpml_languages ) ) {
					foreach ( $wpml_languages as $key => $language ) {
						if ( $key != $default_lang ) {
							$multi_lang[] = $key;
						}
					}
				}
			} elseif ( class_exists( 'Polylang' ) ) {
				/*Polylang*/
				$languages    = pll_languages_list();
				$default_lang = pll_default_language( 'slug' );
				foreach ( $languages as $language ) {
					if ( $language == $default_lang ) {
						continue;
					}
					$multi_lang[] = $language;
				}
			}
			for ( $i = 0; $i < count( $messenger_rules['send_time'] ); $i ++ ) {
				$this->last_time = $i == count( $messenger_rules['send_time'] ) - 1 ? true : false;
				$time_to_send    = current_time( 'timestamp' ) - intval( $messenger_rules['time_to_send'][ $i ] ) * Data::get_instance()->case_unit( $messenger_rules['unit'][ $i ] );

				$lists = $this->query->get_list_message_to_send( $time_to_send, $messenger_rules['send_time'][ $i ] );

				if ( is_array( $lists ) && count( $lists ) > 0 ) {
					if ( isset( $messenger_rules['message'][ $i ] ) ) {
						$messenger_text = $messenger_rules['message'][ $i ];
						if ( $multi_lang && isset( $item['current_lang'] ) && ! empty( $item['current_lang'] ) ) {
							if ( isset( $messenger_rules['message_' . $item['current_lang']] )
							     && isset( $messenger_rules['message_' . $item['current_lang']][ $i ] ) ) {
								$messenger_text = $messenger_rules['message_' . $item['current_lang']][ $i ];
							}
						}
						$this->messenger_content( $lists, $messenger_text );
					}
				}
			}
		}
	}

	public function send_test_whatsapp() {
		check_ajax_referer( 'wacv_ajax_nonce', 'nonce' );

		$phone_number = ! empty( $_POST['phone_number'] ) ? sanitize_text_field( wp_unslash( $_POST['phone_number'] ) ) : '';
		$phone_id = ! empty( $_POST['phone_id'] ) ? sanitize_text_field( wp_unslash( $_POST['phone_id'] ) ) : '';
		$app_token = ! empty( $_POST['app_token'] ) ? sanitize_text_field( wp_unslash( $_POST['app_token'] ) ) : '';
		$message_temp = ! empty( $_POST['message_temp'] ) ? sanitize_text_field( wp_unslash( $_POST['message_temp'] ) ) : '';
		if ( $phone_number && $phone_id && $app_token && $message_temp ) {
			$result = $this->fb_api->send_test_message_wa( $phone_id, $phone_number, $app_token, $message_temp );
//			$result = $this->fb_api->send_message_wa( $phone_id, $phone_number, $app_token, $message_temp );
//			self::send_reminder_whatsapp();
			if ( ( is_object( $result ) || is_array( $result ) ) && $result['code'] == 200 ) {
				wp_send_json_success( esc_html__( 'message sent successfully', 'woo-abandoned-cart-recovery' ) );
			} else {
				if ( ( is_object( $result ) || is_array( $result ) ) && isset( $result['message'] ) ) {
					wp_send_json_error( $result['message'] );
				} else {
					wp_send_json_error( $result );
				}
			}
		} else {
			wp_send_json_error( __( 'Please fill all fields', 'woo-abandoned-cart-recovery' ) );
		}
		wp_die();
	}

	public function send_reminder_whatsapp() {
		if ( ! empty( $this->settings['whatsapp_rules'] ) && ! empty( $this->settings['whatsapp_enable'] ) ) {
			$this->api_init();
			$whatsapp_rules = $this->settings['whatsapp_rules'];
			$multi_lang = array();
			if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
				global $sitepress;
				$default_lang           = $sitepress->get_default_language();
				$wpml_languages              = icl_get_languages( 'skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str' );

				if ( count( $wpml_languages ) ) {
					foreach ( $wpml_languages as $key => $language ) {
						if ( $key != $default_lang ) {
							$multi_lang[] = $key;
						}
					}
				}
			} elseif ( class_exists( 'Polylang' ) ) {
				/*Polylang*/
				$languages    = pll_languages_list();
				$default_lang = pll_default_language( 'slug' );
				foreach ( $languages as $language ) {
					if ( $language == $default_lang ) {
						continue;
					}
					$multi_lang[] = $language;
				}
			}

			for ( $i = 0; $i < count( $whatsapp_rules['send_time'] ); $i ++ ) {
				$this->last_time_wa = $i == count( $whatsapp_rules['send_time'] ) - 1 ? true : false;
				$time_to_send    = current_time( 'timestamp' ) - intval( $whatsapp_rules['time_to_send'][ $i ] ) * Data::get_instance()->case_unit( $whatsapp_rules['unit'][ $i ] );

				$lists = $this->query->get_list_whatsapp_to_send( $time_to_send, $whatsapp_rules['send_time'][ $i ] );

				if ( is_array( $lists ) && count( $lists ) > 0 ) {
					if ( isset( $whatsapp_rules['message'][ $i ] ) ) {
						$messenger_text = $whatsapp_rules['message'][ $i ];
						if ( $multi_lang && isset( $item['current_lang'] ) && ! empty( $item['current_lang'] ) ) {
							if ( isset( $whatsapp_rules['message_' . $item['current_lang']] )
							     && isset( $whatsapp_rules['message_' . $item['current_lang']][ $i ] ) ) {
								$messenger_text = $whatsapp_rules['message_' . $item['current_lang']][ $i ];
							}
						}

						$this->whatsapp_content( $lists, $messenger_text, $whatsapp_rules['send_time'][ $i ] );
					}
				}
			}
		}
	}

	public function whatsapp_content( $lists, $message, $time ) {
		$phone_id = $this->settings['whatsapp_phone_id'];
		$page_token = $this->settings['whatsapp_permanent_token'];

		if ( ! $phone_id || ! $page_token ) {

			return;
		}

		foreach ( $lists as $item ) {
			$phone_number     = $item->billing_phone;
			$customer_name    = $item->billing_first_name;
			$customer_surname = $item->billing_last_name;
			$country          = $item->billing_country;
			if ( $item->user_type == 'member' ) {
				$phone_number     = get_user_meta( $item->user_id, 'billing_phone', true );
				$country          = get_user_meta( $item->user_id, 'billing_country', true );
				$customer_name    = get_user_meta( $item->user_id, 'billing_first_name', true );
				$customer_surname = get_user_meta( $item->user_id, 'billing_last_name', true );
			}
			if ( ! empty( $item->user_id ) && ! empty( $phone_number ) ) {
				try {
					$phoneNumberObject = $this->phoneNumberUtil->parse( $phone_number, $country );
					$is_phone          = $this->phoneNumberUtil->isPossibleNumber( $phoneNumberObject );
				} catch ( \Exception $e ) {
					if ( true === WP_DEBUG ) {
						error_log( $e->getMessage() );
					}
				}
				$acr_id   = $item->id;

				if ( $is_phone && $phoneNumberObject ) {
					$phone_formated = $this->phoneNumberUtil->format( $phoneNumberObject, $this->format_e164 );
					$sent_email_id = uniqid() . $item->id;
					$checkout_url  = $this->link_checkout( $item->id, $sent_email_id );
					$checkout_url  = str_replace( 'http:', 'https:', $checkout_url );
					$customer_infor = [
						'customer_name' => $customer_name,
						'customer_surname' => $customer_surname
					];

					$result = $this->fb_api->send_message_wa( $phone_id, $phone_formated, $page_token, $message, $checkout_url, $customer_infor );

					if ( ( is_object( $result ) || is_array( $result ) ) && $result['code'] == 200 ) {
						$complete = $this->last_time_wa ? '1' : null;
						$this->query->update_abd_cart_record( array( 'whatsapp_sent' => $time, 'whatsapp_complete' => $complete ), array( 'id' => $acr_id ) );
					}
				} else {
					$this->query->update_abd_cart_record( array( 'valid_phone' => 1 ), array( 'id' => $acr_id ) );
				}
			}
		}

		return;
	}

	public function messenger_content( $lists, $message ) {
		$user_token = $this->settings['user_token'];
		$page_id    = $this->settings['page_id'];

		if ( ! $user_token || ! $page_id ) {
			return;
		}

		if ( ! $this->page_access_token ) {
			$page_access_token       = $this->fb_api->Get_Access_Token_Page( $user_token, $page_id );
			$this->page_access_token = $page_token = $page_access_token['access_token'];
		} else {
			$page_token = $this->page_access_token;
		}

		if ( ! $page_token ) {
			return;
		}

		foreach ( $lists as $item ) {
			$user_ref = $item->meta_value ? $item->meta_value : $item->user_ref;

			if ( ! empty( $item->user_id ) && ! empty( $user_ref ) ) {

				$array_product = array();

				$cart          = json_decode( $item->abandoned_cart_info );
				$sent_email_id = uniqid() . $item->id;
				$checkout_url  = $this->link_checkout( $item->id, $sent_email_id );

				foreach ( $cart->cart as $pd ) {
					$pid     = $pd->variation_id ? $pd->variation_id : $pd->product_id;
					$product = wc_get_product( $pid );
					if ( $product ) {
						$button_view_url_product = str_replace( 'http:', 'https:', get_the_permalink( $pd->product_id ) );
						$pd_img                  = get_the_post_thumbnail_url( $pid, 'woocommerce_thumbnail' );
						$pd_img                  = $pd_img ? $pd_img : get_the_post_thumbnail_url( $pd->product_id, 'woocommerce_thumbnail' );

						$array_product[] = array(

							"title" => $product->get_name(),

							"subtitle" => $product->get_short_description(),

							"image_url" => str_replace( 'http:', 'https:', $pd_img ),

							"default_action" => array(
								"type"                 => "web_url",
								"url"                  => $button_view_url_product,
								"messenger_extensions" => true,
								"webview_height_ratio" => "tall",
								"fallback_url"         => $button_view_url_product
							),

							"buttons" => array(
								array(
									"type"  => "web_url",
									"url"   => str_replace( 'http:', 'https:', $checkout_url ),
									"title" => __( 'Checkout', 'woo-abandoned-cart-recovery' )
								)
							)
						);
					}
				}

				if ( count( $array_product ) > 0 ) {
					$send_text     = $this->fb_api->send_message_text_user_ref( $page_id, $page_token, $message, $user_ref );
					$send_abd_cart = $this->fb_api->send_message_abd_cart_user_ref( $page_id, $page_token, $user_ref, $array_product );
					if ( ! is_string( $send_abd_cart ) && ! empty( $send_abd_cart->asArray() || $send_text ) ) {
						$complete = $this->last_time ? '1' : null;
						$this->query->update_abd_cart_record(
							array( 'messenger_sent' => $item->messenger_sent + 1, 'messenger_complete' => $complete ),
							array( 'id' => $item->id )
						);
						$this->query->insert_email_history( 'messenger', $item->id, $sent_email_id );
					}
				}
			}
		}
	}

	public function link_checkout( $acr_id, $sent_email_id ) {

		$pass       = get_option( 'wacv_private_key' );
		$url_encode = Aes_Ctr::encrypt( $acr_id . '&' . $sent_email_id . '&0', $pass, 256 );

		return site_url( 'wacv?wacv_recover=cart_link&valid=' ) . $url_encode;
	}


}
