<?php
/**
 * Created by PhpStorm.
 * User: Villatheme-Thanh
 * Date: 08-06-19
 * Time: 12:01 PM
 */

namespace WACVP\Inc\Settings;

use WACVP\Inc\Functions;
use WACVP\Inc\Email\ActiveCampaign_WACV;
use WACVP\Inc\Email\Sendinblue_WACV;
use WACVP\Inc\Email\GetResponse_WACV;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Email_Settings extends Admin_Settings {

	protected static $instance = null;

	public function __construct() {
	}

	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	public function setting_page() {
		?>
        <div class="vi-ui bottom attached tab segment tab-admin" data-tab="email">

            <h4><?php esc_html_e( 'Email for Abandoned Cart', 'woo-abandoned-cart-recovery' ) ?></h4>
            <table class="wacv-table">
				<?php
				$this->checkbox_option( 'send_email_to_member', __( "Send mail reminder to members", 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'send_email_to_guest', __( "Send mail reminder to guest", 'woo-abandoned-cart-recovery' ) );
				$this->text_option( 'email_reply_address', __( "Reply Emails to", 'woo-abandoned-cart-recovery' ) );
				$this->send_email_rules_settings( 'email_rules', true );
				$this->checkbox_option( 'email_to_admin_when_cart_recover', __( "Notification to Admin", 'woo-abandoned-cart-recovery' ), __( 'Send a notification email to admin whenever a cart is recovered', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'price_incl_tax', __( "Price include tax", 'woo-abandoned-cart-recovery' ), __( 'Display price include tax if tax is enabled & prices entered exclusive of tax', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'email_item_link', __( "Product link", 'woo-abandoned-cart-recovery' ), __( 'Enable product link in the product detail in the abandoned emails', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'email_item_price', __( "Product price", 'woo-abandoned-cart-recovery' ), __( 'Enable product price in the product detail in the abandoned emails', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'email_item_price_calc', __( "Display current price", 'woo-abandoned-cart-recovery' ), __( 'Enable to display current product price in the product detail in Abandoned email, disable to show price saved in abandoned cart', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'email_new_cart_block', __( "Template use new cart block", 'woo-abandoned-cart-recovery' ), __( 'Use new cart block to edit more text, if you have old template, please edit and replace by new cart block to use', 'woo-abandoned-cart-recovery' ) );
				$this->checkbox_option( 'enable_active_campaign', __( "Active Campaign", 'woo-abandoned-cart-recovery' ), __( 'Once abandoned email is sent out to customers, use Active Campaign to achieve customer email', 'woo-abandoned-cart-recovery' ) );
				$this->text_option( 'active_campaign_api', __( 'Active Campaign API Key', 'woo-abandoned-cart-recovery' ), '', '', true );
				$this->text_option( 'active_campaign_url', __( 'Active Campaign API URL', 'woo-abandoned-cart-recovery' ), '', '', true );
				$ac_mail_list  = array();
				$data_enable_ac = self::get_field( 'enable_active_campaign' );
				if ($data_enable_ac) {
					$activeCampain = new ActiveCampaign_WACV();
					$ac_mail_lists = $activeCampain->get_lists();
					if ( is_array( $ac_mail_lists ) ) {
						foreach ( $ac_mail_lists as $_list ) {
							$ac_mail_list[ $_list->id ] = $_list->name;
						}
					}
				}
                $this->select_option( 'active_campaign_list', $ac_mail_list, __( "Active Campaign contacts list", 'woo-abandoned-cart-recovery' ) );

                $this->checkbox_option( 'enable_sendinblue', __( "Sendinblue", 'woo-abandoned-cart-recovery' ), __( 'Once abandoned email is sent out to customers, use Sendinblue to achieve customer email', 'woo-abandoned-cart-recovery' ) );
				$this->text_option( 'sendinblue_api', __( 'Sendinblue API Key', 'woo-abandoned-cart-recovery' ), '', '', true );
				$sib_mail_list  = array();
				$data_enable_sendinblue = self::get_field( 'enable_sendinblue' );
				if ($data_enable_sendinblue) {
					$sendinblue = new Sendinblue_WACV();
					$sib_mail_lists = $sendinblue->get_lists();
					if ( is_array( $sib_mail_lists ) ) {
						foreach ( $sib_mail_lists as $_list ) {
							$sib_mail_list[ $_list->id ] = $_list->name;
						}
					}
                }
				$this->select_option( 'sendinblue_list', $sib_mail_list, __( "Sendinblue contacts list", 'woo-abandoned-cart-recovery' ), '', '', true );

				$this->checkbox_option( 'enable_getresponse', __( "GetResponse", 'woo-abandoned-cart-recovery' ), __( 'Once abandoned email is sent out to customers, use GetResponse to achieve customer email', 'woo-abandoned-cart-recovery' ) );
				$data_enable_gr = self::get_field( 'enable_getresponse' );
				$mail_list_gr = [];
				if ($data_enable_gr) {
					$getresponse      = new GetResponse_WACV();
					$mail_lists_gr    = $getresponse->get_lists();
					if ( is_array( $mail_lists_gr ) ) {
						foreach ( $mail_lists_gr as $_list ) {
							$mail_list_gr[ $_list->campaignId ] = $_list->name;
						}
					}
				}
				$this->text_option( 'getresponse_api', __( 'GetResponse API Key', 'woo-abandoned-cart-recovery' ), '', '', true );
				$this->select_option( 'getresponse_list', $mail_list_gr, __( "GetResponse campaign (list)", 'woo-abandoned-cart-recovery' ) );

				?>
            </table>
            <hr>

            <h4><?php esc_html_e( 'Email for Abandoned Order', 'woo-abandoned-cart-recovery' ) ?></h4>
            <table class="wacv-table">
				<?php
				$order_stt = array(
					'wc-failed'    => 'Failed',
					'wc-cancelled' => 'Cancelled',
					'wc-pending'   => 'Pending payment',
					'wc-on-hold'   => "On hold",
				);

				if ( defined( 'WC_BLOCKS_IS_FEATURE_PLUGIN' ) && WC_BLOCKS_IS_FEATURE_PLUGIN ) {
					$order_stt['wc-checkout-draft'] = 'Draft';
				}

				$this->checkbox_option( 'enable_reminder_order', __( "Enable", 'woo-abandoned-cart-recovery' ), __( 'Send abandoned emails to all specific orders. Please limit email sending to orders created within a specific time and matching certain order statuses. Choose the order statuses and set the time frame below.', 'woo-abandoned-cart-recovery' ) );
				$this->date_time_option( 'reminder_order_time', __( 'Send to orders after date', 'woo-abandoned-cart-recovery' ),
                    __( 'Abandoned Order only send if it created after this time', 'woo-abandoned-cart-recovery' ), 'days' );
				$this->select_option( 'order_stt', $order_stt, __( "Order status", 'woo-abandoned-cart-recovery' ), '', '', true );
				$this->send_email_rules_settings( 'abd_orders', true );
				?>
            </table>
            <hr>
            <table class="wacv-table">
				<?php
				$size_options = wp_get_additional_image_sizes();
				$r            = [ '' => esc_html__( 'Original' ) ];
				foreach ( $size_options as $key => $args ) {
					$height    = $args['height'] ? $args['height'] : 'auto';
					$width     = $args['width'] ? $args['width'] : 'auto';
					$r[ $key ] = "{$key} ({$width}x{$height})";
				}
				$this->select_option( 'image_size', $r, __( "Image size", 'woo-abandoned-cart-recovery' ), '', '' );
				?>
            </table>
            <p class="vi-ui yellow message"><?php esc_html_e( 'Note: Recover link will not work with Admin role', 'woo-abandoned-cart-recovery' ); ?></p>
        </div>
		<?php
	}

	//Email Rules

	public function send_email_rules_settings( $slug, $multilingual = '' ) {
		$data          = self::get_field( $slug );
		$list_template = Functions::get_email_template();
		?>
        <tr>
            <td class="col-1">
                <label><?php esc_html_e( 'Send mail rules', 'woo-abandoned-cart-recovery' ) ?></label>
            </td>

            <td class="col-2">
                <table class="vi-ui celled table wacv-email-rules-table">
                    <thead>
                    <tr>
                        <th><?php esc_html_e( 'Send after', 'woo-abandoned-cart-recovery' ); ?></th>
                        <th><?php esc_html_e( 'Unit', 'woo-abandoned-cart-recovery' ); ?></th>
                        <th><?php esc_html_e( 'Email template', 'woo-abandoned-cart-recovery' ); ?></th>
                        <th><?php esc_html_e( 'Action', 'woo-abandoned-cart-recovery' ); ?></th>
                    </tr>
                    </thead>
                    <tbody class="wacv-<?php echo esc_attr( $slug ) ?>-row-target">
					<?php
					if ( isset( $data['time_to_send'] ) ) {
						$loop = count( $data['time_to_send'] );

						for ( $i = 0; $i < $loop; $i ++ ) { ?>
                            <tr class="wacv-<?php echo esc_attr( $slug ) ?>-row-target" data-index="<?php echo esc_attr( $i ) ?>">
                                <td class="vlt-padding-small cols-1">
                                    <input type="number" name="wacv_params[<?php echo esc_attr( $slug ) ?>][time_to_send][]"
                                           class="vlt-input vlt-border vlt-none-shadow vlt-round"
                                           value="<?php echo esc_attr( $data['time_to_send'][ $i ] ) ?>" min="1">
                                </td>
                                <td class="vlt-padding-small cols-2">
                                    <select name="wacv_params[<?php echo esc_attr( $slug ) ?>][unit][]"
                                            class="vlt-input vlt-border vlt-none-shadow vlt-round">
                                        <option value="minutes" <?php echo $data['unit'][ $i ] == 'minutes' ? 'selected' : ''; ?>><?php esc_html_e( 'minutes', 'woo-abandoned-cart-recovery' ); ?></option>
                                        <option value="hours" <?php echo $data['unit'][ $i ] == 'hours' ? 'selected' : ''; ?>><?php esc_html_e( 'hours', 'woo-abandoned-cart-recovery' ); ?></option>
                                    </select>
                                </td>
                                <td class="vlt-padding-small cols-3">
                                    <select name="wacv_params[<?php echo esc_attr( $slug ) ?>][template][]"
                                            class="wacv-select-email-template vlt-input vlt-border vlt-none-shadow vlt-round">
										<?php
										foreach ( $list_template as $template ) {
											$selected = '';
											if ( isset( $data['template'][ $i ] ) ) {
												$selected = $template['id'] == $data['template'][ $i ] ? 'selected' : '';
											}
											echo "<option value='" . $template['id'] . "' $selected>" . $template['value'] . "</option>";
										}
										?>
                                    </select>
                                    <?php
                                    if ( $multilingual ) {
	                                    if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
		                                    global $sitepress;
		                                    $default_lang           = $sitepress->get_default_language();
		                                    $languages = $langs = icl_get_languages( 'skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str' );
		                                    if ( count( $languages ) ) {
			                                    foreach ( $languages as $key => $language ) {
				                                    if ( $key == $default_lang ) {
					                                    continue;
				                                    }
				                                    ?>
                                                    <p class="wacv-mlg-label"><?php echo esc_html( $language['native_name'] . ':' ) ?></p>
                                                    <select name="wacv_params[<?php echo esc_attr( $slug ) ?>][template<?php echo esc_attr('_' . $key) ?>][]"
                                                            class="wacv-select-email-template vlt-input vlt-border vlt-none-shadow vlt-round">
					                                    <?php
					                                    foreach ( $list_template as $template ) {
						                                    $selected = '';
						                                    if ( isset( $data['template_' . $key][ $i ] ) ) {
							                                    $selected = $template['id'] == $data['template_' . $key][ $i ] ? 'selected' : '';
						                                    }
						                                    echo "<option value='" . $template['id'] . "' $selected>" . $template['value'] . "</option>";
					                                    }
					                                    ?>
                                                    </select>
				                                    <?php
			                                    }
		                                    }
	                                    } elseif ( class_exists( 'Polylang' ) ) {
		                                    $languages = pll_languages_list();
		                                    foreach ( $languages as $language ) {
			                                    $default_lang = pll_default_language( 'slug' );

			                                    if ( $language == $default_lang ) {
				                                    continue;
			                                    }
//			                                    $field_name_mlg = $slug . '_' . $language;
//			                                    $class_mlg    = 'wacv-' . str_replace( '_', '-', $field_name_mlg );
//			                                    $set_name_mlg = $this->set_field( $field_name_mlg, $multi );
			                                    ?>
                                                <p class="wacv-mlg-label"><?php echo esc_html( $language . ':' ) ?></p>
                                                <select name="wacv_params[<?php echo esc_attr( $slug ) ?>][template<?php echo esc_attr('_' . $language) ?>][]"
                                                        class="wacv-select-email-template vlt-input vlt-border vlt-none-shadow vlt-round">
				                                    <?php
				                                    foreach ( $list_template as $template ) {
					                                    $selected = '';
					                                    if ( isset( $data['template_' . $language][ $i ] ) ) {
						                                    $selected = $template['id'] == $data['template_' . $language][ $i ] ? 'selected' : '';
					                                    }
					                                    echo "<option value='" . $template['id'] . "' $selected>" . $template['value'] . "</option>";
				                                    }
				                                    ?>
                                                </select>
			                                    <?php
		                                    }
	                                    }
                                    }
                                    ?>
                                </td>
                                <td align="center" class="vlt-padding-small cols-4">
                                    <button class="wacv-delete-<?php echo esc_attr( $slug ) ?> vi-ui small icon red button"
                                            type="button">
                                        <i class="trash icon"> </i>
                                    </button>
                                </td>
                            </tr>
						<?php }
					} ?>
                    </tbody>
                </table>
                <button type="button" class="wacv-add-<?php echo esc_attr( $slug ) ?> vi-ui small icon green button">
					<?php esc_html_e( 'Add rule', 'woo-abandoned-cart-recovery' ); ?>
                </button>
            </td>
            <td class="col-3"></td>
        </tr>
		<?php
	}
}
