<?php
/**
 * Plugin Name: WooCommerce Abandoned Cart Recovery Premium
 * Plugin URI: https://www.persianscript.ir
 * Description: Capture abandoned cart & send reminder emails to the customers.
 * Version: 1.1.0
 * Author: پرشین اسکریپت
 * Author URI: https://www.persianscript.ir
 * Text Domain: woo-abandoned-cart-recovery
 * Domain Path: /languages
 * Copyright 2019-2023 VillaTheme.com. All rights reserved.
 * Requires at least: 5.0
 * Tested up to: 6.2
 * WC requires at least: 5.0
 * WC tested up to: 7.9
 * Requires PHP: 7.0
 **/

use WACVP\Inc\Data;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
define( 'WACVP_VERSION', '1.1.0' );

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
global $wp_version;

define( 'WACVP_SLUG', 'woocommerce-abandoned-cart-recovery' );
define( 'WACVP_DIR', WP_PLUGIN_DIR . DIRECTORY_SEPARATOR . "woocommerce-abandoned-cart-recovery" . DIRECTORY_SEPARATOR );
define( 'WACVP_LANGUAGES', WACVP_DIR . "languages" . DIRECTORY_SEPARATOR );
define( 'WACVP_INCLUDES', WACVP_DIR . "includes" . DIRECTORY_SEPARATOR );
define( 'WACVP_VIEWS', WACVP_DIR . "views" . DIRECTORY_SEPARATOR );
define( 'WACVP_TEMPLATES', WACVP_INCLUDES . "templates" . DIRECTORY_SEPARATOR );
define( 'WACVP_GUEST_ID_LIMIT', 100000000 );

$wacv_err_message = '';
$require_wp_ver   = '5.0';
$require_php_ver  = '7.0';

if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
	$wacv_err_message = esc_html__( 'Please install and activate WooCommerce to use WooCommerce Abandoned Cart Recovery.', 'woo-abandoned-cart-recovery' );
}
if ( ! version_compare( $wp_version, $require_wp_ver, '>' ) ) {
	$wacv_err_message = sprintf( esc_html__( "Please update WordPress version %s to use WooCommerce Abandoned Cart Recovery.", 'woo-abandoned-cart-recovery' ), esc_html( $require_wp_ver ) );
}

if ( ! version_compare( phpversion(), $require_php_ver, '>=' ) ) {
	$wacv_err_message = sprintf( esc_html__( "Please update PHP version at least %s to use WooCommerce Abandoned Cart Recovery.", 'woo-abandoned-cart-recovery' ), esc_html( $require_php_ver ) );
}

//if ( ! class_exists( 'VillaTheme_Require_Environment' ) ) {
//	require_once WACVP_INCLUDES . "support.php";
//}

//$wacvp_environment = new VillaTheme_Require_Environment( [
//		'plugin_name'     => 'WooCommerce Abandoned Cart Recovery Premium',
//		'php_version'     => '7.0',
//		'wp_version'      => '5.0',
//		'wc_version'      => '5.0',
//		'require_plugins' => [
//			[
//				'slug' => 'woocommerce',
//				'name' => 'WooCommerce',
//			],
//		]
//	]
//);

if ( $wacv_err_message ) {
	if ( ! function_exists( 'wacv_notification' ) ) {
		function wacv_notification() {
			global $wacv_err_message;
			?>
			<div id="message" class="error">
				<p><?php echo esc_html($wacv_err_message) ?></p>
			</div>
			<?php
		}
	}
	add_action( 'admin_notices', 'wacv_notification' );
	deactivate_plugins( plugin_basename( __FILE__ ) );
} else {
	require_once WACVP_INCLUDES . "define.php";
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wacvp_add_action_links' );
	register_activation_hook( __FILE__, 'wacvp_activate' );

	//Compatible with High-Performance order storage (COT)
	add_action( 'before_woocommerce_init', 'wacvp_before_woocommerce_init' );

	function wacvp_before_woocommerce_init() {
		if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}

	function wacvp_add_action_links( $links ) {
		$settings_link = '<a href="' . admin_url( 'admin.php?page=wacv_settings' ) . '">' . __( 'Settings', 'woo-abandoned-cart-recovery' ) . '</a>';
		array_unshift( $links, $settings_link );

		return $links;
	}

	function wacvp_activate( $network_wide ) {
		require_once WACVP_INCLUDES . "plugin.php";
		$wacv_plugin = \WACVP\Inc\Plugin::get_instance();
		$wacv_plugin->activate( $network_wide );
	}

	function wacvp_activate_new_blog( $blog_id ) {
		if ( is_plugin_active_for_network( 'woocommerce-abandoned-cart-recovery/woocommerce-abandoned-cart-recovery.php' ) ) {
			switch_to_blog( $blog_id );
			require_once WACVP_INCLUDES . "plugin.php";
			$wacv_plugin = \WACVP\Inc\Plugin::get_instance();
			$wacv_plugin->single_active();
			restore_current_blog();
		}
	}

	add_action( 'wpmu_new_blog', 'wacvp_activate_new_blog' );

	function wacv_delete_plugin_tables( $tables, $blog_id ) {
		if ( empty( $blog_id ) || 1 == $blog_id || $blog_id != $GLOBALS['blog_id'] ) {
			return $tables;
		}
		global $wpdb;
		$blog_prefix   = $wpdb->get_blog_prefix( $blog_id );
		$plugin_tables = array(
			'wacv_abandoned_cart_record',
			'wacv_guest_info_record',
			'wacv_email_history',
			'wacv_cart_log'
		);
		foreach ( $plugin_tables as $k => $table ) {
			$tables[ $table ] = $blog_prefix . $table;
		}

		return $tables;
	}

	add_filter( 'wpmu_drop_tables', 'wacv_delete_plugin_tables', 10, 2 );

	function WACV_Data() {
		return Data::get_instance();
	}
}
